#
# spec file for package kew
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kew
Version:        2.8.1
Release:        1.3
Summary:        A command-line music player
License:        GPL-2.0-only
URL:            https://github.com/ravachol/kew
Source:         %{url}/archive/v%{version}/kew-%{version}.tar.gz
BuildRequires:  freeimage-devel
BuildRequires:  libnotify-devel
%if 0%{?suse_version} < 1600
BuildRequires:  clang >= 17
%else
BuildRequires:  gcc >= 13
%endif
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(chafa)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(opusfile)
BuildRequires:  pkgconfig(vorbisfile)

%description
Listen to music in the terminal.

%prep
%autosetup
%if 0%{?suse_version} < 1600
sed -i '1s|gcc|clang|' Makefile
%endif

%build
%make_build

%install
%make_install

%files
%license LICENSE
%doc README*
%{_bindir}/kew
%{_mandir}/man1/kew.1%{?ext_man}

%changelog
* Sat Sep 21 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.8.1
  * Fixed slow loading UI on some machines, because of blocking
    desktop notification.
* Fri Sep 20 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.8
  * Much nicer way to set the music library path on first use.
  * Checks at startup if the music library's modified time has
    changed when using cached library. If it has, update the
    library.
  * Improved search: kew now also shows the album name (directory
    name) of search results, for clarity.
  * You can now use TAB to cycle through the different views.
  * Don't repeat the song notification when enqueuing songs.
  * Fixed issue where kew sometimes couldn't find the cover image
    in the folder.
  * Better handling of songs that cannot be initialized.
  * Removed support for .mp4 files so as to not add a bunch of
    video folders to the music library.
  * Cursor was not reappearing in some cases on FreeBSD after
    program exited.
* Wed Sep  4 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.7.2
  * Add capability to remove the currently playing song from the
    playlist. Press space bar to play the next song in the list.
  * Scrolling now stops immediately after the key is released.
  * Better reset of the terminal at program exit.
  * MPRIS widgets are now updated when switching songs while paused
  * When pressing update library ("u"), it now remembers which
    files are enqueued.
  * No more ugly scroll back buffer in the terminal.
* Mon Aug 26 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.7.0
  * Proper MPRIS and PlayerCtl support. Set volume, stop, seek and
    others now work as expected. You can also switch tracks while
    stopped or paused now. Everything should work except openUri
    and repeat playlist which are not available for now.
  * New (optional) dependency: Libnotify. In practice, adding
    libnotify as a dependency means browsing through music will no
    longer make desktop notifications pile up, instead the one
    visible will update itself. This looks much better. kew uses
    libnotify only if you have it installed, so it should if
    possible be an optional thing during installation.
  * Allows binding of other keys for the different ui views that
    you get with F2-F6.
  * Removed the option to toggle covers on and off by pressing 'c'.
  * Removed build warning on systems with ffmpeg 4.4 installed.
  * Only run one instance of kew at a time, thanks @werdahias for
    the suggestion.
  * If you exit the kew with 0%% volume, when you open it next time,
    volume will be at 10%%. To avoid confusion.
  * Handle SIGHUP not only SIGINT.
  * Prints error message instead of crashing on Fedora when
    playing unsupported .m4a files. This problem is related to
    ffmpeg free/non-free versions. You need the non-free version.
  * Fixed issue where special characters in the song title could
    cause mpris widgets to not work correctly.
- add libnotify-devel BuildRequires: needed for v2.7.0
* Sat Jul  6 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.6.0
  * New command: "kew albums", similar to "kew all" but it queues
    one album randomly after the other. Thank you @the-boar for the
    suggestion.
  * Fixed bug where sometimes kew couldn't find a suitable name for
    a playlist file (created by pressing x).
  * Made it so that seeking jumps in more reasonable smaller
    increments when not in song view. Previously it could jump 30
    seconds at a time.
  * Rolled back code related to symlinked directories, it didn't
    work with freebsd, possibly others.
- Add clang BuildRequires: build for leap
* Tue Jul  2 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.5.1
  * Fixed bug where desktop notifications could lead to a short
    stall of the app at startup if notify-send wasn't installed.
  * Search: Removed duplicate search result name variable. This
    means search results will now have a very low memory footprint.
  * Symlinked directories should work better now. Works best if
    the symlink and the destination directory has the same name.
* Mon Jun 17 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.5.0
  * Fuzzy search! Press F5 to search your library.
  * You can now quit with Esc. Handy when you are in search view,
    because pressing 'q' will just add that letter to the search
    string.
  * Fixed issue where after completing a playthrough of a playlist
    and then starting over, only the first song would be played.
  * Fine tuning of the spectrum visualizer. Still not perfect but
    I think this one is better. I might be wrong though.
  * Made scrolling quicker.
* Wed Mar 27 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.4.4
  * Fixed no sound when playing a flac or mp3 song twice, then
    enqueuing another.
  * Don't save every change to the playlist when running the
    special playlist w*ith 'kew .', only add the songs added by
    pressing '.'.
  * Removed a compiler warning and a few other minor fixes.
* Tue Mar 12 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.4.3
  * Fixed covers not being perfectly square on some terminals.
  * Fixed playlist selector could get 'stuck'.
  * Code refactoring and minor improvements to playlist view.
  * Moved the files kewrc and kewlibrary config files from
    XDG_CONFIG_HOME into XDG_CONFIG_HOME/kew/ or ~/.config/kew.
* Thu Feb 29 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.4.2
  * Fixed a few issues related to reading and writing the library.
* Mon Feb 26 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.4.1
  * Improved album cover color mode. Press 'i' to try this.
  * To accelerate startup times, there is now a library cache.
    This feature is optional and can be enabled in the settings
    file (kewrc). If the library loading process is slow, you'll
    be prompted to consider using the cache.
  * You can now press 'u' to update the library in case you've
    added or removed songs.
  * Faster "kew all". It now bases its playlist on the library
    instead of scanning everything a second time.
  * Fixed when running the special playlist with "kew .", the app
    sometimes became unresponsive when adding / deleting.
  * Code refactoring and cleanup.
* Sun Feb 18 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.4
  * Much faster song loading/skipping.
  * New settings: configurable colors. These are configured in the
    kewrc file (in ~/.config/ or wherever your config files are)
    with instructions there.
  * New setting: hidehelp. Hides the help text on library view
    and playlist view.
  * New setting: hidelogo. Prints the artist name as well as the
    song title at the top instead of a logo.
  * Fixed an issue with shuffle that could lead to a crash.
  * Fixed an issue where it could crash at the end of the
    playlist.
  * Fixed an issue where in some types of music libraries you
    couldn't scroll all the way to the bottom.
  * Fixed notifications not notifying on songs with spaces in
    cover art url.
  * Fixed sometimes not being able to switch song.
  * Further adjustments to the visualizer.
  * .aac and .mp4 file support.
  * New option: -q. Quits right after playing the playlist (same
    as --quitonstop).
  * Improved help text.
  * The visualizer now (finally!) works like it's supposed to for
    all formats.
  * Proper clean up and restore cursor when using CTRL-C to quit
    the app.
  * Don't refresh track view twice when skipping to the previous
    song.
  * Notifications of currently playing song through notify-send.
    New setting: allowNotifications. Set to 0 to disable
    notifications.
  * Fixed an issue that could lead to a crash when switching
    songs.
  * Fixed an issue with switching opus songs that could also lead
    to a crash.
  * Plus other bug fixes.
* Sat Feb  3 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.2.1
  * Fixed issue related to enqueuing/dequeuing the next song.
* Sat Feb  3 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.2
  * This update mostly contains improvements to stability.
  * M4a file decoding is no longer done by calling ffmpeg
    externally, it's (finally) done like the other file formats.
    This should make kew more stable, responsive and it should
    consume less memory when playing m4a files.
  * kew now starts the first time with your system volume as the
    volume, after that it remembers the last volume it exited with
    and uses that.
  * kew now picks up and starts using the cover color without the
    user having to first go to track view.
* Fri Jan 26 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.1.1
  * Fixed a few issues related to passing cover art url and track
    length to mpris. Should now display cover and progress
    correctly in widgets on gnome/wayland.
* Mon Jan 22 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.4
  * You can now add "-e" or "--exact" in your searches to return an
    exact (not case sensitive) match. This can be helpful when two
    albums have a similar name, and you want to specify you want
    one or the other. Example: kew -e basement popstar.
  * Fixed issue where pressing del on the playlist changed view to
    track view.
* Mon Jan 15 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.3
  * Fixed issue where sometimes the last of enqueued songs where
    being played instead of the first.
  * F4 is bound to show track view, and shown on the last row, so
    that the track view isn't hidden from new users.
* Fri Jan 12 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.2
  * moved mutex initialization code
  * small graphical tweaks
  * show songs before enqueueing everthing
* Thu Jan 11 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 2.0.1
  * New view: Library. Shows the contents of the music library.
    From there you can add songs to the playlist.
  * Delete items from the playlist by pressing Del.
  * You can flip through pages of the library or playlist by
    pressing Page Up and Page Down.
  * Starting kew with no arguments now takes you to the library.
  * After the playlist finishes playing, the library is shown,
    instead of the app exiting.
  * To run kew with all songs shuffled like you could before, just
    type "kew all" in the terminal.
  * Running kew with the argument --quitonstop, enables the old
    behavior of exiting when finished.
  * Removed the playlist duration counter. It caused problems when
    coupled with the new features of being able to remove and add
    songs while audio is playing.
  * New ascii logo! This one takes up much less space.
  * kew now shows which song is playing on top of the library and
    playlist views.
  * Volume is now set at 50%% at the start.
  * Also many bug fixes.
* Sun Dec 10 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.11
  * Now shows volume percentage. New alternate key for raising
    volume: =.
  * Fixed bug where on a small window size, the Nerd Fonts for
    seeking, repeat and shuffle when all three enabled could mess
    up the visualizer.
* Mon Dec  4 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.10
  * Improved config file, with more information on how to make key
    bindings with special keys for instance.
  * Changing the volume is now for just kew, not the master volume
    of your system.
  * Switching songs now unpauses the player.
  * Fixed issue of potential crash when uninitializing decoders.
* Fri Dec  1 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.9
  * Fixed a potential dead-lock situation.
  * Fixed one instance of wrong metadata/cover being displayed for
    a song on rare occasions.
  * Fixed an issue that could lead to a crash when switching songs.
  * Fixed issue of potential crash when closing audio file.
  * Fixed playlist showing the previous track as the current one.
  * Much improved memory allocation handling in visualizer.
  * Playlist builder now ignores hidden directories.
* Wed Nov 29 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.8.1
  * Fixed bug where kew for no reason stopped playing audio but
    kept counting elapsed seconds.
  * Fixed bugs relating to showing the playlist.
  * Fixed bug where trying to seek in ogg files led to strange
    behavior. Now seeking in ogg is entirely disabled.
  * More colorful visualizer bars when using album cover colors.
* Tue Nov 28 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.8
  * visualizer bars now grow and decrease smoothly (if your
    terminal supports unicode).
  * m4a files quit properly.
* Mon Nov 27 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.7.4
  * kew is now interactive when paused.
  * Fixed issue with crashing after a few plays with repeat
    enabled.
  * Deletes cover images from cache after playing the file.
* Sun Nov 26 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.7.3
  * Fixed issue with crashing after a few plays with repeat
    enabled.
  * Fixed issue with crash after seeking to the end of songs a few
    times.
* Thu Nov 23 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.7.2
  * Introduced Nerd Font glyphs for things like pause, repeat, fast
    forward and so on.
  * More minor fixes.
  * Fixed issues with the makefile.
* Mon Nov 20 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 1.7.1
  * Fixes a few issues in 1.7.0
* Fri Nov 17 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
